@@ -3,10 +3,13 @@
 #  Licensed under the MIT License (MIT). See LICENSE in the repo root for license information.
 #  ------------------------------------------------------------------------------------------
 
-from health_ml.utils.logging import AzureMLLogger, log_learning_rate, log_on_epoch
+from health_ml.utils.logging import AzureMLLogger, AzureMLProgressBar, log_learning_rate, log_on_epoch
+from health_ml.utils.diagnostics import BatchTimeCallback
 
 __all__ = [
     "AzureMLLogger",
+    "AzureMLProgressBar",
+    "BatchTimeCallback",
     "log_learning_rate",
     "log_on_epoch",
 ]
